"""
byte_elastalert_utils.common.http
=================================

common functionality related to HTTP
"""
import json
# @TODO: Python 2 compatibility
try:
    from urllib.request import urlopen, Request
except ImportError:
    from urllib2 import urlopen, Request
try:
    from ssl import create_default_context
except ImportError:  # our Jenkins is so ancient, no create_default_context :cry:
    create_default_context = None


def http_json(url, headers=None, data=None, context=None):
    """Perform an HTTP JSON request and returns the results parsed out of JSON
    response. accepts extra headers and possible data (POST), and SSL context

    :param dict headers: dict of HTTP headers
    :param str  data: POST request body data (no data to request with a GET)
    :param ssl.SSLContext context: the customized SSL context
    """
    if headers is None:
        headers = dict()
    if 'Content-type' not in headers:
        headers['Content-type'] = 'application/json'
    if 'Accept' not in headers:
        headers['Accept'] = 'application/json'
    if context is None and create_default_context:
        context = create_default_context()
    req = Request(url, headers=headers, data=data)
    resp = urlopen(req, context=context).read().decode('utf-8')
    if not resp:
        raise RuntimeError('empty response from url "{}"'.format(url))
    return json.loads(resp)
