import sys
from logging import INFO, getLogger, StreamHandler, Formatter


def get_logger(name, level=INFO):
    """Return a logger configured with handlers and formatters
    :param str name: logger name
    :rtype: logging.Logger
    """
    logger = getLogger(name)
    logger.setLevel(level)
    root_handlers = getLogger().handlers
    if not any([is_std_stream_handler(handler) for handler in root_handlers]):
        logger.addHandler(create_stream_handler(level=level))
    return logger


def create_stream_handler(stream=None, level=INFO, log_format='%(levelname)s:%(name)s:%(message)s'):
    """Create a StreamHandler with decent default settings for stdout

    :param file stream: file like object (default is sys.stdout)
    :param int level: logging level for this handler (default is INFO)
    :param str log_format: format of the log message
    :rtype: logging.hanlders.StreamHandler
    """
    if not stream:
        stream = sys.stdout
    stream_handler = StreamHandler(stream)
    stream_handler.setLevel(level)
    stream_handler.setFormatter(Formatter(log_format))
    return stream_handler


def is_std_stream_handler(handler):
    """Determine if a logging handler emits to stdout/stderr
    :param logging.Handler: handler
    :rtype: bool
    """
    return isinstance(handler, StreamHandler) and hasattr(handler, 'stream') and handler.stream in (sys.stdout, sys.stderr)
