"""
byte_elastalert_utils.hypernode.hnapi
=====================================

abstract functionality to communicate with Hypernode API
"""
from byte_elastalert_utils.common.log import get_logger
from byte_elastalert_utils.common.http import http_json


API_TOKEN_PATH = '/etc/elastalert/hypernode-api-token'
APP_INFO_URL = 'https://api.hypernode.com/administration/v1/app/{}'

logger = get_logger(__name__)


def get_api_token():
    """Return the default API token by reading from the default file
    """
    logger.debug('reading Hypernode API token from {}'.format(API_TOKEN_PATH))
    with open(API_TOKEN_PATH, 'rt') as fh:
        return fh.read().strip()


class HnApi():
    def __init__(self, api_token):
        if len(api_token) < 1:
            raise ValueError('invalid Hypernode API api_token. api_token is empty')
        self._api_token = api_token

    def _request(self, url):
        return http_json(
            url,
            headers={
                'Authorization': 'Token {}'.format(self._api_token),
            }
        )

    def get_app_info(self, app_name):
        logger.debug('requesting app info from Hypernode API')
        return self._request(APP_INFO_URL.format(app_name))
